@@ -1,15 +1,19 @@
 {-# LANGUAGE CPP #-}
 
 module Capture (
-#ifdef WIN32
+#if defined(WIN32)
         module Capture.Win32
+#elif defined(DARWIN)
+        module Capture.OSX
 #else
         module Capture.X11
 #endif
         ) where
 
-#ifdef WIN32
+#if defined(WIN32)
 import Capture.Win32
+#elif defined(DARWIN)
+import Capture.OSX
 #else
 import Capture.X11
 #endif
