@@ -36,11 +36,27 @@ captureData = do
         xSetErrorHandler
         let rwin = defaultRootWindow dpy
 
+        -- Desktops
+        current_desktop <- flip catchIOError (\_ -> return "") $ do
+            a <- internAtom dpy "_NET_CURRENT_DESKTOP" False
+            p <- getWindowProperty32 dpy a rwin
+            let desk_index = do {[d] <- p; return (fromIntegral d)}
+
+            a <- internAtom dpy "_NET_DESKTOP_NAMES" False
+            tp <- getTextProperty dpy rwin a
+            names <- wcTextPropertyToTextList dpy tp
+
+            return $ case desk_index of
+                  Nothing -> ""
+                  Just n -> if 0 <= n && n < length names
+                            then names !! n
+                            else show n
+        -- Windows
         a <- internAtom dpy "_NET_CLIENT_LIST" False
         p <- getWindowProperty32 dpy a rwin
 
         wins <- case p of
-                Just wins -> return (map fromIntegral wins)
+                Just wins -> filterM (isInteresting dpy) (map fromIntegral wins)
                 Nothing   -> return []
 
         (fsubwin,_) <- getInputFocus dpy
@@ -54,7 +70,7 @@ captureData = do
         it <- fromIntegral `fmap` getXIdleTime dpy
 
         closeDisplay dpy
-        return $ CaptureData winData it
+        return $ CaptureData winData it (T.pack current_desktop)
 
 getWindowTitle :: Display -> Window -> IO String
 getWindowTitle dpy =  myFetchName dpy
@@ -71,6 +87,17 @@ followTreeUntil dpy cond = go
                               if p == 0 then return w
                                         else go p 
 
+-- | Ignore, for example, Desktop and Docks windows
+isInteresting :: Display -> Window -> IO Bool
+isInteresting d w = do
+    a <- internAtom d "_NET_WM_WINDOW_TYPE" False
+    dock <- internAtom d "_NET_WM_WINDOW_TYPE_DOCK" False
+    desk <- internAtom d "_NET_WM_WINDOW_TYPE_DESKTOP" False
+    mbr <- getWindowProperty32 d a w
+    case mbr of
+        Just [r] -> return $ fromIntegral r `notElem` [dock, desk]
+        _        -> return True
+
 -- | better than fetchName from X11, as it supports _NET_WM_NAME and unicode
 --
 -- Code taken from XMonad.Managehook.title
